<?php
/**
* @package Shared_lib
*
* A collection of useful functions for use in PHP projects
*
* db.php contains Database related functions
*
* @copyright Copyright (C) 2011 B Tasker
* @license License: GPLV3, see LICENSE
*/



/** Restore a database from a SQL Dump file
*
* @param string sqlFile - Path to the SQL Dump file
* @param string dbuser - Username to use when connecting to the database
* @param string dbpass - Password to use when connecting to the database
* @param string dbname - Database to restore the backup to
*
*/
function restore_MySQLdb_backup($sqlFile,$dbuser,$dbpass,$dbname)
{

// Connect to the database
$link = open_mysql_db($dbhost,$dbuser,$dbpass,"");

// Create the database if it doesn't already exist
$query = "CREATE DATABASE IF NOT EXISTS $dbname";
mysql_query($query);

// Close the connection
close_mysql_db($link);

// Restore the backup
$restorebackup = "mysql -u ".$dbuser." --password=".$dbpass." ".$dbname." < ".$sqlFile;
exec($restorebackup);

}



/** Make string safe for use in MySQL 
*
* @param string string - the string to make safe
*
* @return - String made safe
*/
function make_string_safe($string)
{

$string = mysql_real_escape_string($string);
$string = htmlspecialchars($string);
return $string;

}



/** Make each element of an array safe
* @param array array - The array to walk through and make safe
*/
function make_array_safe($array)
{
array_walk_recursive($array, 'sql_escape');
return $array;
}



function sql_escape(&$var)
{
$var  = mysql_real_escape_string($var);
return $var;

}



/**
* Re-order a table 
*
* @param string dbhost - the DB server to connect to
* @param string dbuser - the username to use when connecting
* @param string dbpass - the password to use when connecting
* @param string table - The table to re-order
* @param string orderby - The column to sort by
* @param string order - Expects A or D - Ascending or Descending. Default A
*
* @return true/false - was the operation successful?
*
*/
function table_maintenance($dbhost,$dbuser,$dbpass,$table,$orderby,$order)
{
// Open the database
$link = open_mysql_db($dbhost,$dbuser,$dbpass,$dbname);

// build the query
$query = "ALTER TABLE $table ORDER BY $orderby";

if ($order == "A"){
$query = "$query" . " ASC";
      }else{
$query = "$query" . " DESC";
      }

// run the query
$result = mysql_query($query);

// Close the database
close_mysql_db($link);

return $result;
}



/**
* Connect to a MYSQL DB
*
* @param string dbhost - the MySQL DB server to connect to
* @param string dbuser - the Username to use
* @param string dbpass - The password to use
* @param string dbname - the database to connect to (can be left blank to just connect to the server)
*
* @return link id for the connection
*/
function open_mysql_db($dbhost,$dbuser,$dbpass,$dbname)
{
// Open the Database connection
$link = mysql_connect($dbhost, $dbuser, $dbpass);

if (!$link) {
    die('Could not connect: ' . mysql_error());
}
else
{

// Connect to a specific database if one is named
if (!empty($dbname)){
$db_selected = mysql_select_db($dbname, $link);
if (!$db_selected) {
    die ('Can\'t use ' . $dbname . ': ' . mysql_error());
}

}

return $link;

}
}


/** Close a connection to a MYSQL DB
*
* @param string link - Link id for the connection to close
*
*/
function close_mysql_db($link)
{
mysql_close($link);
}


/** Create a backup of a MySQL Database
* 
*
* @param string tmpdir - Temporary directory to output the SQL backupfile to
* @param string prefix - Filename prefix for the backup file
* @param string dbuser - Username to use when connecting to the DB
* @param string dbpass - Password to use when connecting to the DB
* @param string dbname - Name of the database to connect to
* @param string backupcompress - Should we zip the backupfile (expects Y/N)
*
* @return string containing path to the backupfile
*/
function backup_mysql_db($tmpdir,$prefix,$dbuser,$dbpass,$dbname,$backupcompress)
{
// Create a backup of the database



// Filenaming conventions
$sqlFile = $tmpdir."/".$prefix.date('Y_m_d').".sql";
$attachment = $tmpdir."/".$prefix.date('Y_m_d').".tgz";


// grab the SQL dump
$createbackup = "mysqldump --hex-blob -u ".$dbuser." --password=".$dbpass." ".$dbname." > ".$sqlFile;
exec($createbackup);

$outputfile = $sqlFile;

if ($backupcompress == "Y"){

// Zip it
$createZip = "tar cvzf $attachment $sqlFile";
exec($createZip);
$outputfile = $attachment;
// We no longer require the SQLfile so delete it
unlink($sqlFile);
  }

// return the path to the file
return $outputfile;

}





?>